paint/encode

Values

pub fn from_string(
  string: String,
) -> Result(@internal Picture, json.DecodeError)

Attempt to deserialize a Picture

pub fn to_string(picture: @internal Picture) -> String

Serialize a Picture to a string.

If you wish to store the serialized data, remember that the library currently makes no stability guarantee that the data can be deserialized by future versions of the library

Search Document